from setuptools import setup, find_packages

setup(name='Fosbury',
      version='0.9.4',
      author='Willems Spruijt',
      author_email='willem@fosbury.co',
      description='Python client for Fosbury (http://fosbury.co)',
      packages=find_packages(),
      license='Apache License 2.0')